@@ -13,6 +13,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+import inspect
 from typing import Awaitable, Callable, Dict, Optional, Sequence, Tuple, Union
 import warnings
 
@@ -236,6 +237,9 @@ class CatalogServiceGrpcAsyncIOTransport(CatalogServiceTransport):
             )
 
         # Wrap messages. This must be done after self._grpc_channel exists
+        self._wrap_with_kind = (
+            "kind" in inspect.signature(gapic_v1.method_async.wrap_method).parameters
+        )
         self._prep_wrapped_messages(client_info)
 
     @property
@@ -865,22 +869,22 @@ class CatalogServiceGrpcAsyncIOTransport(CatalogServiceTransport):
     def _prep_wrapped_messages(self, client_info):
         """Precompute the wrapped methods, overriding the base class method to use async wrappers."""
         self._wrapped_methods = {
-            self.create_entry_type: gapic_v1.method_async.wrap_method(
+            self.create_entry_type: self._wrap_method(
                 self.create_entry_type,
                 default_timeout=60.0,
                 client_info=client_info,
             ),
-            self.update_entry_type: gapic_v1.method_async.wrap_method(
+            self.update_entry_type: self._wrap_method(
                 self.update_entry_type,
                 default_timeout=60.0,
                 client_info=client_info,
             ),
-            self.delete_entry_type: gapic_v1.method_async.wrap_method(
+            self.delete_entry_type: self._wrap_method(
                 self.delete_entry_type,
                 default_timeout=60.0,
                 client_info=client_info,
             ),
-            self.list_entry_types: gapic_v1.method_async.wrap_method(
+            self.list_entry_types: self._wrap_method(
                 self.list_entry_types,
                 default_retry=retries.AsyncRetry(
                     initial=1.0,
@@ -895,7 +899,7 @@ class CatalogServiceGrpcAsyncIOTransport(CatalogServiceTransport):
                 default_timeout=60.0,
                 client_info=client_info,
             ),
-            self.get_entry_type: gapic_v1.method_async.wrap_method(
+            self.get_entry_type: self._wrap_method(
                 self.get_entry_type,
                 default_retry=retries.AsyncRetry(
                     initial=1.0,
@@ -910,22 +914,22 @@ class CatalogServiceGrpcAsyncIOTransport(CatalogServiceTransport):
                 default_timeout=60.0,
                 client_info=client_info,
             ),
-            self.create_aspect_type: gapic_v1.method_async.wrap_method(
+            self.create_aspect_type: self._wrap_method(
                 self.create_aspect_type,
                 default_timeout=60.0,
                 client_info=client_info,
             ),
-            self.update_aspect_type: gapic_v1.method_async.wrap_method(
+            self.update_aspect_type: self._wrap_method(
                 self.update_aspect_type,
                 default_timeout=60.0,
                 client_info=client_info,
             ),
-            self.delete_aspect_type: gapic_v1.method_async.wrap_method(
+            self.delete_aspect_type: self._wrap_method(
                 self.delete_aspect_type,
                 default_timeout=60.0,
                 client_info=client_info,
             ),
-            self.list_aspect_types: gapic_v1.method_async.wrap_method(
+            self.list_aspect_types: self._wrap_method(
                 self.list_aspect_types,
                 default_retry=retries.AsyncRetry(
                     initial=1.0,
@@ -940,7 +944,7 @@ class CatalogServiceGrpcAsyncIOTransport(CatalogServiceTransport):
                 default_timeout=60.0,
                 client_info=client_info,
             ),
-            self.get_aspect_type: gapic_v1.method_async.wrap_method(
+            self.get_aspect_type: self._wrap_method(
                 self.get_aspect_type,
                 default_retry=retries.AsyncRetry(
                     initial=1.0,
@@ -955,22 +959,22 @@ class CatalogServiceGrpcAsyncIOTransport(CatalogServiceTransport):
                 default_timeout=60.0,
                 client_info=client_info,
             ),
-            self.create_entry_group: gapic_v1.method_async.wrap_method(
+            self.create_entry_group: self._wrap_method(
                 self.create_entry_group,
                 default_timeout=60.0,
                 client_info=client_info,
             ),
-            self.update_entry_group: gapic_v1.method_async.wrap_method(
+            self.update_entry_group: self._wrap_method(
                 self.update_entry_group,
                 default_timeout=60.0,
                 client_info=client_info,
             ),
-            self.delete_entry_group: gapic_v1.method_async.wrap_method(
+            self.delete_entry_group: self._wrap_method(
                 self.delete_entry_group,
                 default_timeout=60.0,
                 client_info=client_info,
             ),
-            self.list_entry_groups: gapic_v1.method_async.wrap_method(
+            self.list_entry_groups: self._wrap_method(
                 self.list_entry_groups,
                 default_retry=retries.AsyncRetry(
                     initial=1.0,
@@ -985,7 +989,7 @@ class CatalogServiceGrpcAsyncIOTransport(CatalogServiceTransport):
                 default_timeout=60.0,
                 client_info=client_info,
             ),
-            self.get_entry_group: gapic_v1.method_async.wrap_method(
+            self.get_entry_group: self._wrap_method(
                 self.get_entry_group,
                 default_retry=retries.AsyncRetry(
                     initial=1.0,
@@ -1000,12 +1004,12 @@ class CatalogServiceGrpcAsyncIOTransport(CatalogServiceTransport):
                 default_timeout=60.0,
                 client_info=client_info,
             ),
-            self.create_entry: gapic_v1.method_async.wrap_method(
+            self.create_entry: self._wrap_method(
                 self.create_entry,
                 default_timeout=60.0,
                 client_info=client_info,
             ),
-            self.update_entry: gapic_v1.method_async.wrap_method(
+            self.update_entry: self._wrap_method(
                 self.update_entry,
                 default_retry=retries.AsyncRetry(
                     initial=1.0,
@@ -1020,12 +1024,12 @@ class CatalogServiceGrpcAsyncIOTransport(CatalogServiceTransport):
                 default_timeout=60.0,
                 client_info=client_info,
             ),
-            self.delete_entry: gapic_v1.method_async.wrap_method(
+            self.delete_entry: self._wrap_method(
                 self.delete_entry,
                 default_timeout=60.0,
                 client_info=client_info,
             ),
-            self.list_entries: gapic_v1.method_async.wrap_method(
+            self.list_entries: self._wrap_method(
                 self.list_entries,
                 default_retry=retries.AsyncRetry(
                     initial=1.0,
@@ -1040,7 +1044,7 @@ class CatalogServiceGrpcAsyncIOTransport(CatalogServiceTransport):
                 default_timeout=20.0,
                 client_info=client_info,
             ),
-            self.get_entry: gapic_v1.method_async.wrap_method(
+            self.get_entry: self._wrap_method(
                 self.get_entry,
                 default_retry=retries.AsyncRetry(
                     initial=1.0,
@@ -1055,7 +1059,7 @@ class CatalogServiceGrpcAsyncIOTransport(CatalogServiceTransport):
                 default_timeout=20.0,
                 client_info=client_info,
             ),
-            self.lookup_entry: gapic_v1.method_async.wrap_method(
+            self.lookup_entry: self._wrap_method(
                 self.lookup_entry,
                 default_retry=retries.AsyncRetry(
                     initial=1.0,
@@ -1070,7 +1074,7 @@ class CatalogServiceGrpcAsyncIOTransport(CatalogServiceTransport):
                 default_timeout=20.0,
                 client_info=client_info,
             ),
-            self.search_entries: gapic_v1.method_async.wrap_method(
+            self.search_entries: self._wrap_method(
                 self.search_entries,
                 default_retry=retries.AsyncRetry(
                     initial=1.0,
@@ -1085,11 +1089,50 @@ class CatalogServiceGrpcAsyncIOTransport(CatalogServiceTransport):
                 default_timeout=60.0,
                 client_info=client_info,
             ),
+            self.get_location: self._wrap_method(
+                self.get_location,
+                default_timeout=None,
+                client_info=client_info,
+            ),
+            self.list_locations: self._wrap_method(
+                self.list_locations,
+                default_timeout=None,
+                client_info=client_info,
+            ),
+            self.cancel_operation: self._wrap_method(
+                self.cancel_operation,
+                default_timeout=None,
+                client_info=client_info,
+            ),
+            self.delete_operation: self._wrap_method(
+                self.delete_operation,
+                default_timeout=None,
+                client_info=client_info,
+            ),
+            self.get_operation: self._wrap_method(
+                self.get_operation,
+                default_timeout=None,
+                client_info=client_info,
+            ),
+            self.list_operations: self._wrap_method(
+                self.list_operations,
+                default_timeout=None,
+                client_info=client_info,
+            ),
         }
 
+    def _wrap_method(self, func, *args, **kwargs):
+        if self._wrap_with_kind:  # pragma: NO COVER
+            kwargs["kind"] = self.kind
+        return gapic_v1.method_async.wrap_method(func, *args, **kwargs)
+
     def close(self):
         return self.grpc_channel.close()
 
+    @property
+    def kind(self) -> str:
+        return "grpc_asyncio"
+
     @property
     def delete_operation(
         self,
