@@ -13,6 +13,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+import inspect
 from typing import Awaitable, Callable, Dict, Optional, Sequence, Tuple, Union
 import warnings
 
@@ -233,6 +234,9 @@ class ContentServiceGrpcAsyncIOTransport(ContentServiceTransport):
             )
 
         # Wrap messages. This must be done after self._grpc_channel exists
+        self._wrap_with_kind = (
+            "kind" in inspect.signature(gapic_v1.method_async.wrap_method).parameters
+        )
         self._prep_wrapped_messages(client_info)
 
     @property
@@ -479,22 +483,22 @@ class ContentServiceGrpcAsyncIOTransport(ContentServiceTransport):
     def _prep_wrapped_messages(self, client_info):
         """Precompute the wrapped methods, overriding the base class method to use async wrappers."""
         self._wrapped_methods = {
-            self.create_content: gapic_v1.method_async.wrap_method(
+            self.create_content: self._wrap_method(
                 self.create_content,
                 default_timeout=60.0,
                 client_info=client_info,
             ),
-            self.update_content: gapic_v1.method_async.wrap_method(
+            self.update_content: self._wrap_method(
                 self.update_content,
                 default_timeout=60.0,
                 client_info=client_info,
             ),
-            self.delete_content: gapic_v1.method_async.wrap_method(
+            self.delete_content: self._wrap_method(
                 self.delete_content,
                 default_timeout=60.0,
                 client_info=client_info,
             ),
-            self.get_content: gapic_v1.method_async.wrap_method(
+            self.get_content: self._wrap_method(
                 self.get_content,
                 default_retry=retries.AsyncRetry(
                     initial=1.0,
@@ -508,7 +512,7 @@ class ContentServiceGrpcAsyncIOTransport(ContentServiceTransport):
                 default_timeout=60.0,
                 client_info=client_info,
             ),
-            self.get_iam_policy: gapic_v1.method_async.wrap_method(
+            self.get_iam_policy: self._wrap_method(
                 self.get_iam_policy,
                 default_retry=retries.AsyncRetry(
                     initial=1.0,
@@ -522,12 +526,12 @@ class ContentServiceGrpcAsyncIOTransport(ContentServiceTransport):
                 default_timeout=60.0,
                 client_info=client_info,
             ),
-            self.set_iam_policy: gapic_v1.method_async.wrap_method(
+            self.set_iam_policy: self._wrap_method(
                 self.set_iam_policy,
                 default_timeout=60.0,
                 client_info=client_info,
             ),
-            self.test_iam_permissions: gapic_v1.method_async.wrap_method(
+            self.test_iam_permissions: self._wrap_method(
                 self.test_iam_permissions,
                 default_retry=retries.AsyncRetry(
                     initial=1.0,
@@ -541,7 +545,7 @@ class ContentServiceGrpcAsyncIOTransport(ContentServiceTransport):
                 default_timeout=60.0,
                 client_info=client_info,
             ),
-            self.list_content: gapic_v1.method_async.wrap_method(
+            self.list_content: self._wrap_method(
                 self.list_content,
                 default_retry=retries.AsyncRetry(
                     initial=1.0,
@@ -555,11 +559,50 @@ class ContentServiceGrpcAsyncIOTransport(ContentServiceTransport):
                 default_timeout=60.0,
                 client_info=client_info,
             ),
+            self.get_location: self._wrap_method(
+                self.get_location,
+                default_timeout=None,
+                client_info=client_info,
+            ),
+            self.list_locations: self._wrap_method(
+                self.list_locations,
+                default_timeout=None,
+                client_info=client_info,
+            ),
+            self.cancel_operation: self._wrap_method(
+                self.cancel_operation,
+                default_timeout=None,
+                client_info=client_info,
+            ),
+            self.delete_operation: self._wrap_method(
+                self.delete_operation,
+                default_timeout=None,
+                client_info=client_info,
+            ),
+            self.get_operation: self._wrap_method(
+                self.get_operation,
+                default_timeout=None,
+                client_info=client_info,
+            ),
+            self.list_operations: self._wrap_method(
+                self.list_operations,
+                default_timeout=None,
+                client_info=client_info,
+            ),
         }
 
+    def _wrap_method(self, func, *args, **kwargs):
+        if self._wrap_with_kind:  # pragma: NO COVER
+            kwargs["kind"] = self.kind
+        return gapic_v1.method_async.wrap_method(func, *args, **kwargs)
+
     def close(self):
         return self.grpc_channel.close()
 
+    @property
+    def kind(self) -> str:
+        return "grpc_asyncio"
+
     @property
     def delete_operation(
         self,
