@@ -13,6 +13,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+import inspect
 from typing import Awaitable, Callable, Dict, Optional, Sequence, Tuple, Union
 import warnings
 
@@ -234,6 +235,9 @@ class DataScanServiceGrpcAsyncIOTransport(DataScanServiceTransport):
             )
 
         # Wrap messages. This must be done after self._grpc_channel exists
+        self._wrap_with_kind = (
+            "kind" in inspect.signature(gapic_v1.method_async.wrap_method).parameters
+        )
         self._prep_wrapped_messages(client_info)
 
     @property
@@ -519,56 +523,95 @@ class DataScanServiceGrpcAsyncIOTransport(DataScanServiceTransport):
     def _prep_wrapped_messages(self, client_info):
         """Precompute the wrapped methods, overriding the base class method to use async wrappers."""
         self._wrapped_methods = {
-            self.create_data_scan: gapic_v1.method_async.wrap_method(
+            self.create_data_scan: self._wrap_method(
                 self.create_data_scan,
                 default_timeout=None,
                 client_info=client_info,
             ),
-            self.update_data_scan: gapic_v1.method_async.wrap_method(
+            self.update_data_scan: self._wrap_method(
                 self.update_data_scan,
                 default_timeout=None,
                 client_info=client_info,
             ),
-            self.delete_data_scan: gapic_v1.method_async.wrap_method(
+            self.delete_data_scan: self._wrap_method(
                 self.delete_data_scan,
                 default_timeout=None,
                 client_info=client_info,
             ),
-            self.get_data_scan: gapic_v1.method_async.wrap_method(
+            self.get_data_scan: self._wrap_method(
                 self.get_data_scan,
                 default_timeout=None,
                 client_info=client_info,
             ),
-            self.list_data_scans: gapic_v1.method_async.wrap_method(
+            self.list_data_scans: self._wrap_method(
                 self.list_data_scans,
                 default_timeout=None,
                 client_info=client_info,
             ),
-            self.run_data_scan: gapic_v1.method_async.wrap_method(
+            self.run_data_scan: self._wrap_method(
                 self.run_data_scan,
                 default_timeout=None,
                 client_info=client_info,
             ),
-            self.get_data_scan_job: gapic_v1.method_async.wrap_method(
+            self.get_data_scan_job: self._wrap_method(
                 self.get_data_scan_job,
                 default_timeout=None,
                 client_info=client_info,
             ),
-            self.list_data_scan_jobs: gapic_v1.method_async.wrap_method(
+            self.list_data_scan_jobs: self._wrap_method(
                 self.list_data_scan_jobs,
                 default_timeout=None,
                 client_info=client_info,
             ),
-            self.generate_data_quality_rules: gapic_v1.method_async.wrap_method(
+            self.generate_data_quality_rules: self._wrap_method(
                 self.generate_data_quality_rules,
                 default_timeout=None,
                 client_info=client_info,
             ),
+            self.get_location: self._wrap_method(
+                self.get_location,
+                default_timeout=None,
+                client_info=client_info,
+            ),
+            self.list_locations: self._wrap_method(
+                self.list_locations,
+                default_timeout=None,
+                client_info=client_info,
+            ),
+            self.cancel_operation: self._wrap_method(
+                self.cancel_operation,
+                default_timeout=None,
+                client_info=client_info,
+            ),
+            self.delete_operation: self._wrap_method(
+                self.delete_operation,
+                default_timeout=None,
+                client_info=client_info,
+            ),
+            self.get_operation: self._wrap_method(
+                self.get_operation,
+                default_timeout=None,
+                client_info=client_info,
+            ),
+            self.list_operations: self._wrap_method(
+                self.list_operations,
+                default_timeout=None,
+                client_info=client_info,
+            ),
         }
 
+    def _wrap_method(self, func, *args, **kwargs):
+        if self._wrap_with_kind:  # pragma: NO COVER
+            kwargs["kind"] = self.kind
+        return gapic_v1.method_async.wrap_method(func, *args, **kwargs)
+
     def close(self):
         return self.grpc_channel.close()
 
+    @property
+    def kind(self) -> str:
+        return "grpc_asyncio"
+
     @property
     def delete_operation(
         self,
