@@ -13,6 +13,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+import inspect
 from typing import Awaitable, Callable, Dict, Optional, Sequence, Tuple, Union
 import warnings
 
@@ -237,6 +238,9 @@ class DataplexServiceGrpcAsyncIOTransport(DataplexServiceTransport):
             )
 
         # Wrap messages. This must be done after self._grpc_channel exists
+        self._wrap_with_kind = (
+            "kind" in inspect.signature(gapic_v1.method_async.wrap_method).parameters
+        )
         self._prep_wrapped_messages(client_info)
 
     @property
@@ -1140,22 +1144,22 @@ class DataplexServiceGrpcAsyncIOTransport(DataplexServiceTransport):
     def _prep_wrapped_messages(self, client_info):
         """Precompute the wrapped methods, overriding the base class method to use async wrappers."""
         self._wrapped_methods = {
-            self.create_lake: gapic_v1.method_async.wrap_method(
+            self.create_lake: self._wrap_method(
                 self.create_lake,
                 default_timeout=60.0,
                 client_info=client_info,
             ),
-            self.update_lake: gapic_v1.method_async.wrap_method(
+            self.update_lake: self._wrap_method(
                 self.update_lake,
                 default_timeout=60.0,
                 client_info=client_info,
             ),
-            self.delete_lake: gapic_v1.method_async.wrap_method(
+            self.delete_lake: self._wrap_method(
                 self.delete_lake,
                 default_timeout=60.0,
                 client_info=client_info,
             ),
-            self.list_lakes: gapic_v1.method_async.wrap_method(
+            self.list_lakes: self._wrap_method(
                 self.list_lakes,
                 default_retry=retries.AsyncRetry(
                     initial=1.0,
@@ -1169,7 +1173,7 @@ class DataplexServiceGrpcAsyncIOTransport(DataplexServiceTransport):
                 default_timeout=60.0,
                 client_info=client_info,
             ),
-            self.get_lake: gapic_v1.method_async.wrap_method(
+            self.get_lake: self._wrap_method(
                 self.get_lake,
                 default_retry=retries.AsyncRetry(
                     initial=1.0,
@@ -1183,7 +1187,7 @@ class DataplexServiceGrpcAsyncIOTransport(DataplexServiceTransport):
                 default_timeout=60.0,
                 client_info=client_info,
             ),
-            self.list_lake_actions: gapic_v1.method_async.wrap_method(
+            self.list_lake_actions: self._wrap_method(
                 self.list_lake_actions,
                 default_retry=retries.AsyncRetry(
                     initial=1.0,
@@ -1197,22 +1201,22 @@ class DataplexServiceGrpcAsyncIOTransport(DataplexServiceTransport):
                 default_timeout=60.0,
                 client_info=client_info,
             ),
-            self.create_zone: gapic_v1.method_async.wrap_method(
+            self.create_zone: self._wrap_method(
                 self.create_zone,
                 default_timeout=60.0,
                 client_info=client_info,
             ),
-            self.update_zone: gapic_v1.method_async.wrap_method(
+            self.update_zone: self._wrap_method(
                 self.update_zone,
                 default_timeout=60.0,
                 client_info=client_info,
             ),
-            self.delete_zone: gapic_v1.method_async.wrap_method(
+            self.delete_zone: self._wrap_method(
                 self.delete_zone,
                 default_timeout=60.0,
                 client_info=client_info,
             ),
-            self.list_zones: gapic_v1.method_async.wrap_method(
+            self.list_zones: self._wrap_method(
                 self.list_zones,
                 default_retry=retries.AsyncRetry(
                     initial=1.0,
@@ -1226,7 +1230,7 @@ class DataplexServiceGrpcAsyncIOTransport(DataplexServiceTransport):
                 default_timeout=60.0,
                 client_info=client_info,
             ),
-            self.get_zone: gapic_v1.method_async.wrap_method(
+            self.get_zone: self._wrap_method(
                 self.get_zone,
                 default_retry=retries.AsyncRetry(
                     initial=1.0,
@@ -1240,7 +1244,7 @@ class DataplexServiceGrpcAsyncIOTransport(DataplexServiceTransport):
                 default_timeout=60.0,
                 client_info=client_info,
             ),
-            self.list_zone_actions: gapic_v1.method_async.wrap_method(
+            self.list_zone_actions: self._wrap_method(
                 self.list_zone_actions,
                 default_retry=retries.AsyncRetry(
                     initial=1.0,
@@ -1254,22 +1258,22 @@ class DataplexServiceGrpcAsyncIOTransport(DataplexServiceTransport):
                 default_timeout=60.0,
                 client_info=client_info,
             ),
-            self.create_asset: gapic_v1.method_async.wrap_method(
+            self.create_asset: self._wrap_method(
                 self.create_asset,
                 default_timeout=60.0,
                 client_info=client_info,
             ),
-            self.update_asset: gapic_v1.method_async.wrap_method(
+            self.update_asset: self._wrap_method(
                 self.update_asset,
                 default_timeout=60.0,
                 client_info=client_info,
             ),
-            self.delete_asset: gapic_v1.method_async.wrap_method(
+            self.delete_asset: self._wrap_method(
                 self.delete_asset,
                 default_timeout=60.0,
                 client_info=client_info,
             ),
-            self.list_assets: gapic_v1.method_async.wrap_method(
+            self.list_assets: self._wrap_method(
                 self.list_assets,
                 default_retry=retries.AsyncRetry(
                     initial=1.0,
@@ -1283,7 +1287,7 @@ class DataplexServiceGrpcAsyncIOTransport(DataplexServiceTransport):
                 default_timeout=60.0,
                 client_info=client_info,
             ),
-            self.get_asset: gapic_v1.method_async.wrap_method(
+            self.get_asset: self._wrap_method(
                 self.get_asset,
                 default_retry=retries.AsyncRetry(
                     initial=1.0,
@@ -1297,7 +1301,7 @@ class DataplexServiceGrpcAsyncIOTransport(DataplexServiceTransport):
                 default_timeout=60.0,
                 client_info=client_info,
             ),
-            self.list_asset_actions: gapic_v1.method_async.wrap_method(
+            self.list_asset_actions: self._wrap_method(
                 self.list_asset_actions,
                 default_retry=retries.AsyncRetry(
                     initial=1.0,
@@ -1311,22 +1315,22 @@ class DataplexServiceGrpcAsyncIOTransport(DataplexServiceTransport):
                 default_timeout=60.0,
                 client_info=client_info,
             ),
-            self.create_task: gapic_v1.method_async.wrap_method(
+            self.create_task: self._wrap_method(
                 self.create_task,
                 default_timeout=60.0,
                 client_info=client_info,
             ),
-            self.update_task: gapic_v1.method_async.wrap_method(
+            self.update_task: self._wrap_method(
                 self.update_task,
                 default_timeout=60.0,
                 client_info=client_info,
             ),
-            self.delete_task: gapic_v1.method_async.wrap_method(
+            self.delete_task: self._wrap_method(
                 self.delete_task,
                 default_timeout=60.0,
                 client_info=client_info,
             ),
-            self.list_tasks: gapic_v1.method_async.wrap_method(
+            self.list_tasks: self._wrap_method(
                 self.list_tasks,
                 default_retry=retries.AsyncRetry(
                     initial=1.0,
@@ -1340,7 +1344,7 @@ class DataplexServiceGrpcAsyncIOTransport(DataplexServiceTransport):
                 default_timeout=60.0,
                 client_info=client_info,
             ),
-            self.get_task: gapic_v1.method_async.wrap_method(
+            self.get_task: self._wrap_method(
                 self.get_task,
                 default_retry=retries.AsyncRetry(
                     initial=1.0,
@@ -1354,7 +1358,7 @@ class DataplexServiceGrpcAsyncIOTransport(DataplexServiceTransport):
                 default_timeout=60.0,
                 client_info=client_info,
             ),
-            self.list_jobs: gapic_v1.method_async.wrap_method(
+            self.list_jobs: self._wrap_method(
                 self.list_jobs,
                 default_retry=retries.AsyncRetry(
                     initial=1.0,
@@ -1368,12 +1372,12 @@ class DataplexServiceGrpcAsyncIOTransport(DataplexServiceTransport):
                 default_timeout=60.0,
                 client_info=client_info,
             ),
-            self.run_task: gapic_v1.method_async.wrap_method(
+            self.run_task: self._wrap_method(
                 self.run_task,
                 default_timeout=None,
                 client_info=client_info,
             ),
-            self.get_job: gapic_v1.method_async.wrap_method(
+            self.get_job: self._wrap_method(
                 self.get_job,
                 default_retry=retries.AsyncRetry(
                     initial=1.0,
@@ -1387,27 +1391,27 @@ class DataplexServiceGrpcAsyncIOTransport(DataplexServiceTransport):
                 default_timeout=60.0,
                 client_info=client_info,
             ),
-            self.cancel_job: gapic_v1.method_async.wrap_method(
+            self.cancel_job: self._wrap_method(
                 self.cancel_job,
                 default_timeout=60.0,
                 client_info=client_info,
             ),
-            self.create_environment: gapic_v1.method_async.wrap_method(
+            self.create_environment: self._wrap_method(
                 self.create_environment,
                 default_timeout=60.0,
                 client_info=client_info,
             ),
-            self.update_environment: gapic_v1.method_async.wrap_method(
+            self.update_environment: self._wrap_method(
                 self.update_environment,
                 default_timeout=60.0,
                 client_info=client_info,
             ),
-            self.delete_environment: gapic_v1.method_async.wrap_method(
+            self.delete_environment: self._wrap_method(
                 self.delete_environment,
                 default_timeout=60.0,
                 client_info=client_info,
             ),
-            self.list_environments: gapic_v1.method_async.wrap_method(
+            self.list_environments: self._wrap_method(
                 self.list_environments,
                 default_retry=retries.AsyncRetry(
                     initial=1.0,
@@ -1421,7 +1425,7 @@ class DataplexServiceGrpcAsyncIOTransport(DataplexServiceTransport):
                 default_timeout=60.0,
                 client_info=client_info,
             ),
-            self.get_environment: gapic_v1.method_async.wrap_method(
+            self.get_environment: self._wrap_method(
                 self.get_environment,
                 default_retry=retries.AsyncRetry(
                     initial=1.0,
@@ -1435,16 +1439,55 @@ class DataplexServiceGrpcAsyncIOTransport(DataplexServiceTransport):
                 default_timeout=60.0,
                 client_info=client_info,
             ),
-            self.list_sessions: gapic_v1.method_async.wrap_method(
+            self.list_sessions: self._wrap_method(
                 self.list_sessions,
                 default_timeout=None,
                 client_info=client_info,
             ),
+            self.get_location: self._wrap_method(
+                self.get_location,
+                default_timeout=None,
+                client_info=client_info,
+            ),
+            self.list_locations: self._wrap_method(
+                self.list_locations,
+                default_timeout=None,
+                client_info=client_info,
+            ),
+            self.cancel_operation: self._wrap_method(
+                self.cancel_operation,
+                default_timeout=None,
+                client_info=client_info,
+            ),
+            self.delete_operation: self._wrap_method(
+                self.delete_operation,
+                default_timeout=None,
+                client_info=client_info,
+            ),
+            self.get_operation: self._wrap_method(
+                self.get_operation,
+                default_timeout=None,
+                client_info=client_info,
+            ),
+            self.list_operations: self._wrap_method(
+                self.list_operations,
+                default_timeout=None,
+                client_info=client_info,
+            ),
         }
 
+    def _wrap_method(self, func, *args, **kwargs):
+        if self._wrap_with_kind:  # pragma: NO COVER
+            kwargs["kind"] = self.kind
+        return gapic_v1.method_async.wrap_method(func, *args, **kwargs)
+
     def close(self):
         return self.grpc_channel.close()
 
+    @property
+    def kind(self) -> str:
+        return "grpc_asyncio"
+
     @property
     def delete_operation(
         self,
