@@ -13,6 +13,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+import inspect
 from typing import Awaitable, Callable, Dict, Optional, Sequence, Tuple, Union
 import warnings
 
@@ -232,6 +233,9 @@ class MetadataServiceGrpcAsyncIOTransport(MetadataServiceTransport):
             )
 
         # Wrap messages. This must be done after self._grpc_channel exists
+        self._wrap_with_kind = (
+            "kind" in inspect.signature(gapic_v1.method_async.wrap_method).parameters
+        )
         self._prep_wrapped_messages(client_info)
 
     @property
@@ -486,22 +490,22 @@ class MetadataServiceGrpcAsyncIOTransport(MetadataServiceTransport):
     def _prep_wrapped_messages(self, client_info):
         """Precompute the wrapped methods, overriding the base class method to use async wrappers."""
         self._wrapped_methods = {
-            self.create_entity: gapic_v1.method_async.wrap_method(
+            self.create_entity: self._wrap_method(
                 self.create_entity,
                 default_timeout=60.0,
                 client_info=client_info,
             ),
-            self.update_entity: gapic_v1.method_async.wrap_method(
+            self.update_entity: self._wrap_method(
                 self.update_entity,
                 default_timeout=60.0,
                 client_info=client_info,
             ),
-            self.delete_entity: gapic_v1.method_async.wrap_method(
+            self.delete_entity: self._wrap_method(
                 self.delete_entity,
                 default_timeout=60.0,
                 client_info=client_info,
             ),
-            self.get_entity: gapic_v1.method_async.wrap_method(
+            self.get_entity: self._wrap_method(
                 self.get_entity,
                 default_retry=retries.AsyncRetry(
                     initial=1.0,
@@ -515,7 +519,7 @@ class MetadataServiceGrpcAsyncIOTransport(MetadataServiceTransport):
                 default_timeout=60.0,
                 client_info=client_info,
             ),
-            self.list_entities: gapic_v1.method_async.wrap_method(
+            self.list_entities: self._wrap_method(
                 self.list_entities,
                 default_retry=retries.AsyncRetry(
                     initial=1.0,
@@ -529,17 +533,17 @@ class MetadataServiceGrpcAsyncIOTransport(MetadataServiceTransport):
                 default_timeout=60.0,
                 client_info=client_info,
             ),
-            self.create_partition: gapic_v1.method_async.wrap_method(
+            self.create_partition: self._wrap_method(
                 self.create_partition,
                 default_timeout=60.0,
                 client_info=client_info,
             ),
-            self.delete_partition: gapic_v1.method_async.wrap_method(
+            self.delete_partition: self._wrap_method(
                 self.delete_partition,
                 default_timeout=60.0,
                 client_info=client_info,
             ),
-            self.get_partition: gapic_v1.method_async.wrap_method(
+            self.get_partition: self._wrap_method(
                 self.get_partition,
                 default_retry=retries.AsyncRetry(
                     initial=1.0,
@@ -553,7 +557,7 @@ class MetadataServiceGrpcAsyncIOTransport(MetadataServiceTransport):
                 default_timeout=60.0,
                 client_info=client_info,
             ),
-            self.list_partitions: gapic_v1.method_async.wrap_method(
+            self.list_partitions: self._wrap_method(
                 self.list_partitions,
                 default_retry=retries.AsyncRetry(
                     initial=1.0,
@@ -567,11 +571,50 @@ class MetadataServiceGrpcAsyncIOTransport(MetadataServiceTransport):
                 default_timeout=60.0,
                 client_info=client_info,
             ),
+            self.get_location: self._wrap_method(
+                self.get_location,
+                default_timeout=None,
+                client_info=client_info,
+            ),
+            self.list_locations: self._wrap_method(
+                self.list_locations,
+                default_timeout=None,
+                client_info=client_info,
+            ),
+            self.cancel_operation: self._wrap_method(
+                self.cancel_operation,
+                default_timeout=None,
+                client_info=client_info,
+            ),
+            self.delete_operation: self._wrap_method(
+                self.delete_operation,
+                default_timeout=None,
+                client_info=client_info,
+            ),
+            self.get_operation: self._wrap_method(
+                self.get_operation,
+                default_timeout=None,
+                client_info=client_info,
+            ),
+            self.list_operations: self._wrap_method(
+                self.list_operations,
+                default_timeout=None,
+                client_info=client_info,
+            ),
         }
 
+    def _wrap_method(self, func, *args, **kwargs):
+        if self._wrap_with_kind:  # pragma: NO COVER
+            kwargs["kind"] = self.kind
+        return gapic_v1.method_async.wrap_method(func, *args, **kwargs)
+
     def close(self):
         return self.grpc_channel.close()
 
+    @property
+    def kind(self) -> str:
+        return "grpc_asyncio"
+
     @property
     def delete_operation(
         self,
