@@ -1662,11 +1662,11 @@ class ListEntriesRequest(proto.Message):
             AND, OR, NOT can be used in the filter. Wildcard "*" can be
             used, but for entry_type the full project id or number needs
             to be provided. Example filter expressions:
-            "entry_source.display_name=AnExampleDisplayName"
-            "entry_type=projects/example-project/locations/global/entryTypes/example-entry_type"
+            `entry_source.display_name=AnExampleDisplayName`
+            `entry_type=projects/example-project/locations/global/entryTypes/example-entry_type`
             `entry_type=projects/example-project/locations/us/entryTypes/a*
-            OR entry_type=projects/another-project/locations/*` "NOT
-            entry_source.display_name=AnotherExampleDisplayName".
+            OR entry_type=projects/another-project/locations/*` `NOT
+            entry_source.display_name=AnotherExampleDisplayName`.
     """
 
     parent: str = proto.Field(
